import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class DecimalTextInputFormatter extends TextInputFormatter {
  RegExp? _exp;

  DecimalTextInputFormatter({
    int decimalRange = 3,
    bool activatedNegativeValues = true,
  }) : assert(
            decimalRange >= 0, 'DecimalTextInputFormatter declaretion error') {
    var dp = (decimalRange > 0) ? '([.][0-9]{0,$decimalRange}){0,1}' : '';
    var num = '[0-9]*$dp';
    if (activatedNegativeValues) {
      _exp = RegExp('^((((-){0,1})|((-){0,1}[0-9]$num))){0,1}\$');
    } else {
      _exp = RegExp('^($num){0,1}\$');
    }
  }

  @override
  TextEditingValue formatEditUpdate(
    TextEditingValue oldValue,
    TextEditingValue newValue,
  ) {
    if (_exp!.hasMatch(newValue.text)) {
      return newValue;
    }
    return oldValue;
  }
}

class CurrencyField extends StatelessWidget {
  final double? initialValue;
  final bool? enabled;
  final FormFieldValidator<double>? validator;
  final FocusNode? focusNode;
  final TextInputAction? textInputAction;
  final Function()? onEditingComplete;
  final bool autofocus;
  final String currency;
  final String labelText;
  final void Function(double?) onChanged;

  const CurrencyField({
    super.key,
    this.initialValue,
    this.validator,
    this.enabled,
    this.focusNode,
    this.textInputAction,
    this.onEditingComplete,
    this.autofocus = false,
    required this.currency,
    required this.labelText,
    required this.onChanged,
  });

  @override
  Widget build(BuildContext context) {
    var validator = this.validator;
    return TextFormField(
      initialValue: initialValue.toString(),
      validator:
          validator == null ? null : (v) => validator(double.tryParse(v ?? '')),
      enabled: enabled,
      keyboardType: const TextInputType.numberWithOptions(decimal: true),
      inputFormatters: [DecimalTextInputFormatter()],
      decoration: InputDecoration(
        labelText: labelText,
        prefixText: currency,
      ),
      autofocus: autofocus,
      focusNode: focusNode,
      onChanged: (v) => onChanged(double.tryParse(v)),
      textInputAction: textInputAction,
      onEditingComplete: onEditingComplete,
    );
  }
}
