import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class NumberField extends StatelessWidget {
  final int? initialValue;
  final FormFieldValidator<int>? validator;
  final bool? autofocus;
  final TextInputAction? textInputAction;
  final Function()? onEditingComplete;
  final String labelText;
  final void Function(int?) onChanged;

  const NumberField({
    super.key,
    this.initialValue,
    this.validator,
    this.autofocus,
    this.textInputAction,
    this.onEditingComplete,
    required this.labelText,
    required this.onChanged,
  });

  @override
  Widget build(BuildContext context) {
    var validator = this.validator;
    return TextFormField(
      initialValue: initialValue.toString(),
      autofocus: autofocus ?? false,
      onChanged: (v) => onChanged(int.tryParse(v)),
      validator:
          validator == null ? null : (v) => validator(int.tryParse(v ?? '')),
      keyboardType: TextInputType.number,
      inputFormatters: [
        FilteringTextInputFormatter.digitsOnly,
      ],
      decoration: InputDecoration(
        labelText: labelText,
      ),
      onEditingComplete: onEditingComplete,
      textInputAction: textInputAction,
    );
  }
}
